@@ -13,7 +13,13 @@ from CveXplore.api.connection.api_db import ApiDatabaseSource
 from CveXplore.common.db_mapping import database_mapping
 from CveXplore.database.connection.mongo_db import MongoDBConnection
 from CveXplore.errors import DatabaseIllegalCollection
-from version import VERSION
+try:
+    from version import VERSION
+except ModuleNotFoundError:
+    _PKG_DIR = os.path.dirname(__file__)
+    version_file = os.path.join(_PKG_DIR, "VERSION")
+    with open(version_file, "r") as fdsec:
+        VERSION = fdsec.read()
 
 
 class CveXplore(object):
@@ -75,7 +81,7 @@ class CveXplore(object):
 
     def get_single_store_entry(self, entry_type, dict_filter={}):
         """
-        Method to perform a query on a *single* collection in the mongodb and return a *single* result.
+        Method to perform a query on a *single* collection in the data source and return a *single* result.
 
         :param entry_type: Which specific store are you querying? Choices are:
                            - capec;
@@ -107,7 +113,7 @@ class CveXplore(object):
 
     def get_single_store_entries(self, query, limit=10):
         """
-        Method to perform a query on a *single* collection in the mongodb and return all of the results.
+        Method to perform a query on a *single* collection in the data source and return all of the results.
 
         :param query: Tuple which contains the entry_type and the dict_filter in a tuple.
                       Choices for entry_type:
@@ -158,7 +164,7 @@ class CveXplore(object):
 
     def get_multi_store_entries(self, *queries, limit=10):
         """
-        Method to perform *multiple* queries on *a single* or *multiple* collections in the mongodb and return the
+        Method to perform *multiple* queries on *a single* or *multiple* collections in the data source and return the
         results.
 
         :param queries: A list of tuples which contains the entry_type and the dict_filter.
